Security Advisories (3)
CVE-2007-4772 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows context-dependent attackers to cause a denial of service (infinite loop) via a crafted regular expression.

CVE-2007-6067 (2008-01-09)

Algorithmic complexity vulnerability in the regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (memory consumption) via a crafted "complex" regular expression with doubly-nested states.

CVE-2017-12652 (2019-07-10)

libpng before 1.6.32 does not properly check the length of chunks against the user limit.

NAME

TickerTape - Display long message in Tk

SYNOPSIS

TickerTape Message

DESCRIPTION

For everyone with a case of Browser envy after using Microsoft's Internet Explorer, here's a perl/tk script only slightly more useful than a script to do <BLINK>. Don't know why I wrote it. Don't know why you'd run it. Maybe if you were writing a ticker tape application. Or had a weird thing for Times Square. Anyway....

tog Terry Greenlaw (on-site @ Lockheed Martin) Encompass Technologies z50816@mip.lasc.lockheed.com terry@encompass.is.net